/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |              (DATASET 0001: FACILITY DIRECTOR INTERVIEW)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02691-0001-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Services Research Outcomes Study, 1995-1996, Dataset 0001"

#delimit ;
label define YEARCOMP  -3 "MISSING" ;
label define MONTH1    -3 "MISSING" -2 "DON'T KNOW" ;
label define YEAR1     -3 "MISSING" ;
label define MONTH2    -3 "MISSING" -2 "DON'T KNOW" ;
label define YEAR2     -3 "MISSING" -2 "DON'T KNOW" ;
label define MONTH3    -3 "MISSING" -2 "DON'T KNOW" ;
label define YEAR3     -3 "MISSING" -2 "DON'T KNOW" ;
label define MONTH4    -3 "MISSING" -2 "DON'T KNOW" ;
label define YEAR4     -3 "MISSING" ;
label define MONTH5    -3 "MISSING" -2 "DON'T KNOW" ;
label define YEAR5     -3 "MISSING" ;
label define CHANGE    1 "Yes" 2 "No" ;
label define OWNER     -3 "MISSING" 1 "Yes" 2 "No" ;
label define ADMIN     -3 "MISSING" 1 "Yes" 2 "No" ;
label define REORG     -3 "MISSING" 1 "Yes" 2 "No" ;
label define OTHCHANG  -3 "MISSING" 1 "Yes" 2 "No" ;
label define NUMCHANG  -3 "MISSING" 1 "Yes" 2 "No" ;
label define OVEFFECT  -3 "MISSING"
                       1 "Major alterations in almost every aspect"
                       2 "Significant changes in at least one aspe"
                       3 "Minor changes only" 4 "No effect" ;
label define EFFECTIV  -3 "MISSING" 1 "Improved clinical effectiveness"
                       2 "Reduced clinical effectiveness" 3 "No change" ;
label define YEAREND   -3 "MISSING" -2 "DON'T KNOW" ;
label define REVENUE   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" ;
label define PUBREV    -3 "MISSING" 1 "Yes" 2 "No" ;
label define PUBREV2   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define PRIVREV   -3 "MISSING" 1 "Yes" 2 "No" ;
label define PRIVREV2  -3 "MISSING" -2 "DON'T KNOW" ;
label define PUBINS    -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define PUBINS2   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" ;
label define NPAYHLF   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define NPAYHLF2  -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" ;
label define OUTPAT    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define HOUR24    -5 "NOT APPLICABLE" -3 "MISSING" ;
label define OTHPROG   -5 "NOT APPLICABLE" -3 "MISSING" ;
label define FULLTIME  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define STAFF1    1 "Yes" 2 "No" ;
label define LEFT1     -3 "MISSING" ;
label define NUMBER1   -3 "MISSING" ;
label define HOURS1    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define WAGE1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFIT1  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF2    1 "Yes" 2 "No" ;
label define LEFT2     -3 "MISSING" ;
label define NUMBER2   -3 "MISSING" ;
label define HOURS2    -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" ;
label define WAGE2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFIT2  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF3    -3 "MISSING" 1 "Yes" 2 "No" ;
label define LEFT3     -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER3   -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS3    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE3     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFIT3  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF4    1 "Yes" 2 "No" ;
label define LEFT4     -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER4   -3 "MISSING" ;
label define HOURS4    -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE4     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define BENEFIT4  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define STAFF5    1 "Yes" 2 "No" ;
label define LEFT5     -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER5   -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS5    -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE5     -3 "MISSING" -2 "DON'T KNOW" ;
label define BENEFIT5  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define STAFF6    1 "Yes" 2 "No" ;
label define LEFT6     -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER6   -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS6    -5 "NOT APPLICABLE" -3 "MISSING" ;
label define WAGE6     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define BENEFIT6  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define STAFF7    1 "Yes" 2 "No" ;
label define LEFT7     -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER7   -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS7    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE7     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFIT7  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF8    1 "Yes" 2 "No" ;
label define LEFT8     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER8   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS8    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE8     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFIT8  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF9    1 "Yes" 2 "No" ;
label define LEFT9     -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER9   -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS9    -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE9     -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" ;
label define BENEFIT9  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF10   1 "Yes" 2 "No" ;
label define LEFT10    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER10  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS10   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE10    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFI10  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF11   -3 "MISSING" 1 "Yes" 2 "No" ;
label define LEFT11    -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER11  -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS11   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE11    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFI11  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF12   1 "Yes" 2 "No" ;
label define LEFT12    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define NUMBER12  -3 "MISSING" -2 "DON'T KNOW" ;
label define HOURS12   -3 "MISSING" -2 "DON'T KNOW" ;
label define WAGE12    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFI12  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define STAFF13   -3 "MISSING" 1 "Yes" 2 "No" ;
label define LEFT13    -3 "MISSING" ;
label define NUMBER13  -3 "MISSING" ;
label define HOURS13   -3 "MISSING" ;
label define WAGE13    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define BENEFI13  -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" ;
label define VOLUNT    -3 "MISSING" 1 "Yes" 2 "No" ;
label define VHOURS    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define VWAGE     -3 "MISSING" -2 "DON'T KNOW" ;
label define OWNFACE   -3 "MISSING" 1 "Yes" 2 "No" ;
label define VALUE     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define VALUE2    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Month" 2 "Year" ;
label define RENT      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define RENT2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Month" 2 "Year" ;
label define UTILITY   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define UTILITY2  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Month" 2 "Year" ;
label define SUPPLY    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define SUPPLY2   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Month" 2 "Year" ;
label define EQUIP     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define OVHEAD    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define OTHCOST   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define PATIENTS  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define FINKNOW   -3 "MISSING" -1 "REFUSED"
                       1 "Extensively based on records"
                       2 "Somewhat based on records" 3 "Based on estimate" ;
label define DATAYR    -3 "MISSING" -2 "DON'T KNOW" 1 "1990" 2 "1993" ;
label define DATADIF   -3 "MISSING"
                       1 "All financial information about the same"
                       2 "1993 figures would be higher"
                       3 "1993 figures would be lower" 4 "Other (SPECIFY)" ;
label define PERCDIFF  -5 "NOT APPLICABLE" -3 "MISSING" ;
label define STATMNT   -3 "MISSING" 1 "Yes" 2 "No" ;
label define COPYST    -3 "MISSING" 1 "Yes, report attached"
                       2 "Yes, report to be mailed"
                       3 "No, not specific enough to be useful"
                       4 "No, confidential" 5 "No, other reasons (SPECIFY)" ;
label define PARTIC    -3 "MISSING" 1 "A great extent" 2 "A moderate extent"
                       3 "A small extent" ;
label define ABSTIN    -3 "MISSING" 1 "A great extent" 2 "A moderate extent"
                       3 "A small extent" 4 "No extent" ;
label define FOLLOW    -3 "MISSING" 1 "A great extent" 2 "A moderate extent"
                       3 "A small extent" 4 "No extent" ;
label define PHONE     -3 "MISSING" 1 "Yes" 2 "No" ;
label define MAIL      -3 "MISSING" 1 "Yes" 2 "No" ;
label define INTVIEW   -3 "MISSING" 1 "Yes" 2 "No" ;
label define OTHMETH   -3 "MISSING" 1 "Yes" 2 "No" ;
label define DATACOL1  -3 "MISSING" 1 "Yes" 2 "No" ;
label define DATACOL2  -3 "MISSING" 1 "Yes" 2 "No" ;
label define DATACOL3  -3 "MISSING" 1 "Yes" 2 "No" ;
label define REPORT    -3 "MISSING" 1 "Yes" 2 "No" ;
label define COPYREP   -3 "MISSING" 1 "Yes, report attached"
                       2 "Yes, report to be mailed"
                       3 "No, not specific enough to be useful"
                       4 "No, confidential" 5 "No, other reasons (SPECIFY)" ;
label define ALUMNI    -3 "MISSING" 1 "Yes" 2 "No" ;
label define JCANO     -3 "MISSING" 1 "Yes" 2 "No" ;
label define CARF      -3 "MISSING" 1 "Yes" 2 "No" ;
label define MODE      1 "Inpatient" 2 "Residential"
                       3 "Outpatient Methadone Maintenance"
                       4 "Outpatient Drug-Free" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace FAC_ID = . if (FAC_ID <= -1 )
replace YEARCOMP = . if (YEARCOMP <= -1 )
replace MONTH1 = . if (MONTH1 <= -1 )
replace YEAR1 = . if (YEAR1 <= -1 )
replace MONTH2 = . if (MONTH2 <= -1 )
replace YEAR2 = . if (YEAR2 <= -1 )
replace MONTH3 = . if (MONTH3 <= -1 )
replace YEAR3 = . if (YEAR3 <= -1 )
replace MONTH4 = . if (MONTH4 <= -1 )
replace YEAR4 = . if (YEAR4 <= -1 )
replace MONTH5 = . if (MONTH5 <= -1 )
replace YEAR5 = . if (YEAR5 <= -1 )
replace CHANGE = . if (CHANGE <= -1 )
replace OWNER = . if (OWNER <= -1 )
replace ADMIN = . if (ADMIN <= -1 )
replace REORG = . if (REORG <= -1 )
replace OTHCHANG = . if (OTHCHANG <= -1 )
replace NUMCHANG = . if (NUMCHANG <= -1 )
replace OVEFFECT = . if (OVEFFECT <= -1 )
replace EFFECTIV = . if (EFFECTIV <= -1 )
replace YEAREND = . if (YEAREND <= -1 )
replace REVENUE = . if (REVENUE <= -1 )
replace PUBREV = . if (PUBREV <= -1 )
replace PUBREV2 = . if (PUBREV2 <= -1 )
replace PRIVREV = . if (PRIVREV <= -1 )
replace PRIVREV2 = . if (PRIVREV2 <= -1 )
replace PUBINS = . if (PUBINS <= -1 )
replace PUBINS2 = . if (PUBINS2 <= -1 )
replace NPAYHLF = . if (NPAYHLF <= -1 )
replace NPAYHLF2 = . if (NPAYHLF2 <= -1 )
replace OUTPAT = . if (OUTPAT <= -1 )
replace HOUR24 = . if (HOUR24 <= -1 )
replace OTHPROG = . if (OTHPROG <= -1 )
replace FULLTIME = . if (FULLTIME <= -1 )
replace STAFF1 = . if (STAFF1 <= -1 )
replace LEFT1 = . if (LEFT1 <= -1 )
replace NUMBER1 = . if (NUMBER1 <= -1 )
replace HOURS1 = . if (HOURS1 <= -1 )
replace WAGE1 = . if (WAGE1 <= -1 )
replace BENEFIT1 = . if (BENEFIT1 <= -1 )
replace STAFF2 = . if (STAFF2 <= -1 )
replace LEFT2 = . if (LEFT2 <= -1 )
replace NUMBER2 = . if (NUMBER2 <= -1 )
replace HOURS2 = . if (HOURS2 <= -1 )
replace WAGE2 = . if (WAGE2 <= -1 )
replace BENEFIT2 = . if (BENEFIT2 <= -1 )
replace STAFF3 = . if (STAFF3 <= -1 )
replace LEFT3 = . if (LEFT3 <= -1 )
replace NUMBER3 = . if (NUMBER3 <= -1 )
replace HOURS3 = . if (HOURS3 <= -1 )
replace WAGE3 = . if (WAGE3 <= -1 )
replace BENEFIT3 = . if (BENEFIT3 <= -1 )
replace STAFF4 = . if (STAFF4 <= -1 )
replace LEFT4 = . if (LEFT4 <= -1 )
replace NUMBER4 = . if (NUMBER4 <= -1 )
replace HOURS4 = . if (HOURS4 <= -1 )
replace WAGE4 = . if (WAGE4 <= -1 )
replace BENEFIT4 = . if (BENEFIT4 <= -1 )
replace STAFF5 = . if (STAFF5 <= -1 )
replace LEFT5 = . if (LEFT5 <= -1 )
replace NUMBER5 = . if (NUMBER5 <= -1 )
replace HOURS5 = . if (HOURS5 <= -1 )
replace WAGE5 = . if (WAGE5 <= -1 )
replace BENEFIT5 = . if (BENEFIT5 <= -1 )
replace STAFF6 = . if (STAFF6 <= -1 )
replace LEFT6 = . if (LEFT6 <= -1 )
replace NUMBER6 = . if (NUMBER6 <= -1 )
replace HOURS6 = . if (HOURS6 <= -1 )
replace WAGE6 = . if (WAGE6 <= -1 )
replace BENEFIT6 = . if (BENEFIT6 <= -1 )
replace STAFF7 = . if (STAFF7 <= -1 )
replace LEFT7 = . if (LEFT7 <= -1 )
replace NUMBER7 = . if (NUMBER7 <= -1 )
replace HOURS7 = . if (HOURS7 <= -1 )
replace WAGE7 = . if (WAGE7 <= -1 )
replace BENEFIT7 = . if (BENEFIT7 <= -1 )
replace STAFF8 = . if (STAFF8 <= -1 )
replace LEFT8 = . if (LEFT8 <= -1 )
replace NUMBER8 = . if (NUMBER8 <= -1 )
replace HOURS8 = . if (HOURS8 <= -1 )
replace WAGE8 = . if (WAGE8 <= -1 )
replace BENEFIT8 = . if (BENEFIT8 <= -1 )
replace STAFF9 = . if (STAFF9 <= -1 )
replace LEFT9 = . if (LEFT9 <= -1 )
replace NUMBER9 = . if (NUMBER9 <= -1 )
replace HOURS9 = . if (HOURS9 <= -1 )
replace WAGE9 = . if (WAGE9 <= -1 )
replace BENEFIT9 = . if (BENEFIT9 <= -1 )
replace STAFF10 = . if (STAFF10 <= -1 )
replace LEFT10 = . if (LEFT10 <= -1 )
replace NUMBER10 = . if (NUMBER10 <= -1 )
replace HOURS10 = . if (HOURS10 <= -1 )
replace WAGE10 = . if (WAGE10 <= -1 )
replace BENEFI10 = . if (BENEFI10 <= -1 )
replace STAFF11 = . if (STAFF11 <= -1 )
replace LEFT11 = . if (LEFT11 <= -1 )
replace NUMBER11 = . if (NUMBER11 <= -1 )
replace HOURS11 = . if (HOURS11 <= -1 )
replace WAGE11 = . if (WAGE11 <= -1 )
replace BENEFI11 = . if (BENEFI11 <= -1 )
replace STAFF12 = . if (STAFF12 <= -1 )
replace LEFT12 = . if (LEFT12 <= -1 )
replace NUMBER12 = . if (NUMBER12 <= -1 )
replace HOURS12 = . if (HOURS12 <= -1 )
replace WAGE12 = . if (WAGE12 <= -1 )
replace BENEFI12 = . if (BENEFI12 <= -1 )
replace STAFF13 = . if (STAFF13 <= -1 )
replace LEFT13 = . if (LEFT13 <= -1 )
replace NUMBER13 = . if (NUMBER13 <= -1 )
replace HOURS13 = . if (HOURS13 <= -1 )
replace WAGE13 = . if (WAGE13 <= -1 )
replace BENEFI13 = . if (BENEFI13 <= -1 )
replace VOLUNT = . if (VOLUNT <= -1 )
replace VHOURS = . if (VHOURS <= -1 )
replace VWAGE = . if (VWAGE <= -1 )
replace OWNFACE = . if (OWNFACE <= -1 )
replace VALUE = . if (VALUE <= -1 )
replace VALUE2 = . if (VALUE2 <= -1 )
replace RENT = . if (RENT <= -1 )
replace RENT2 = . if (RENT2 <= -1 )
replace UTILITY = . if (UTILITY <= -1 )
replace UTILITY2 = . if (UTILITY2 <= -1 )
replace SUPPLY = . if (SUPPLY <= -1 )
replace SUPPLY2 = . if (SUPPLY2 <= -1 )
replace EQUIP = . if (EQUIP <= -1 )
replace OVHEAD = . if (OVHEAD <= -1 )
replace OTHCOST = . if (OTHCOST <= -1 )
replace PATIENTS = . if (PATIENTS <= -1 )
replace FINKNOW = . if (FINKNOW <= -1 )
replace DATAYR = . if (DATAYR <= -1 )
replace DATADIF = . if (DATADIF <= -1 )
replace PERCDIFF = . if (PERCDIFF <= -1 )
replace STATMNT = . if (STATMNT <= -1 )
replace COPYST = . if (COPYST <= -1 )
replace PARTIC = . if (PARTIC <= -1 )
replace ABSTIN = . if (ABSTIN <= -1 )
replace FOLLOW = . if (FOLLOW <= -1 )
replace PHONE = . if (PHONE <= -1 )
replace MAIL = . if (MAIL <= -1 )
replace INTVIEW = . if (INTVIEW <= -1 )
replace OTHMETH = . if (OTHMETH <= -1 )
replace DATACOL1 = . if (DATACOL1 <= -1 )
replace DATACOL2 = . if (DATACOL2 <= -1 )
replace DATACOL3 = . if (DATACOL3 <= -1 )
replace REPORT = . if (REPORT <= -1 )
replace COPYREP = . if (COPYREP <= -1 )
replace ALUMNI = . if (ALUMNI <= -1 )
replace JCANO = . if (JCANO <= -1 )
replace CARF = . if (CARF <= -1 )
replace MODE = . if (MODE <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

